@@ -6,20 +6,22 @@ import dask.distributed as distributed
 
 def DNewton(func,grad,hess,bounds,x0,max_iter,*args):
     e = np.inf
-    tol = 1e-6
-    counter = 0
+    tol = 1e-4
+    counter = 1
     x = np.array(x0)
     success = True
+    grad_list = []
     while e > tol:
         counter += 1
         gradient = grad(x,*args)
         hessian  = hess(x,*args)
-        e = np.linalg.norm(gradient)
+        grad_list.append(np.max(gradient))
         try:
             gamma = np.linalg.solve(hessian,-gradient)
-        except Exception as error: 
+        except Exception as error:
             gamma,a,b,c = np.linalg.lstsq(hessian,-gradient)
         x += gamma
+        e = np.max(abs(gamma))
         if misc.out_of_bounds(x,bounds):
             x = np.random.uniform(low = bounds[:,0], high = bounds[:,1], size = len(bounds))
         if counter > max_iter: return x,func(x, *args),e,np.linalg.eig(hess(x, *args))[0], False
